@@ -7,10 +7,14 @@ pub mod acore;
 // ! libs
 #[path = "libs/cursor.rs"]
 pub mod cursor;
+#[path = "libs/escape/escape.rs"]
+pub mod escape;
 #[path = "libs/keycode.rs"]
 pub mod keycode;
 #[path = "libs/keyin.rs"]
 pub mod keyin;
+#[path = "libs/sys/sys.rs"]
+mod sys;
 #[path = "libs/terminal.rs"]
 pub mod terminal;
 
@@ -35,35 +39,17 @@ pub mod physics;
 #[path = "UI/ui.rs"]
 pub mod ui;
 
-pub enum orders {
-    rend,
-    ui,
-    keyboard,
-    misc,
-}
-
-pub struct order {
-    ex: i64,
-}
-impl order {
-    pub fn new() -> order {
-        order { ex: 0 }
+#[path = "test/test.rs"]
+mod test;
+#[cfg(test)]
+mod tests {
+    use crate::test;
+    #[test]
+    fn test() {
+        test::t();
     }
-    pub fn next(&mut self) -> orders {
-        if self.ex == 0 {
-            return orders::rend;
-        }
-        if self.ex == 1 {
-            return orders::ui;
-        }
-        if self.ex == 2 {
-            return orders::keyboard;
-        }
-        if self.ex == 4 {
-            self.ex = 0;
-        }
-        self.ex += 1;
-
-        return orders::misc;
+    #[test]
+    fn test2() {
+        test::check_const();
     }
 }
