@@ -1,5 +1,5 @@
 // checks so everything is in order
-
+use crate::sys;
 pub fn thread_check(threads: i8, lenght: i64) {
     // thread check
     if threads as i64 > lenght {
@@ -9,3 +9,10 @@ pub fn thread_check(threads: i8, lenght: i64) {
         panic!("Threads are odd")
     }
 }
+
+pub fn check_win() {
+    if cfg!(windows) {
+        #[cfg(windows)]
+        sys::windows::enable_virtual_terminal_processing();
+    }
+}
